/**	azlwEMU-SOURCE.js 
	============================================================
	============================================================
	INTELLECTUAL PROPERTY ADVISORY NOTICE
	azlwEMU-SOURCE.js
	azlighthouse works, llc. Email Utilities Javascript Library.
	Copyright (c) 2005, 2006 azlighthouse works, llc.
	All rights reserved.
	http://www.azlighthouse.com
	Permission to use, redistribute, or modify this code, 
	in whole or in part, is hereby expressely granted PROVIDED 
	this Intellectual Property Advisory Notice is included in 
	any derived works.
	============================================================
	============================================================
	
	============================================================
	============================================================
	azlwEMU-SOURCE.js VERSION 1.0	
	This script library contains various utility functions for 
	email. Complete commented source available at 
	http://www.azlighthouse.com
	============================================================
	============================================================
*/

// The following variables should be treated as CONSTANTS 
// should NOT be changed.
var azlwEMU_OBFUSCHARS = "?`~#$^*(){}[]".split("");  
var azlwEMU_CLEARAT = "@";
var azlwEMU_OBFUSAT = "_AT_";
var azlwEMU_DELIM = "|";
var azlwEMU_DIVPREFIX = "divAZLW_EMU_";
var azlwEMU_BYID = (document.getElementById);


function azlwEMUreplaceSubStr(strSource, strSearch, strReplace) {
/**
	========================================================
	This function replaces all occurances of a substring 
	within a string with a new substring, and returns the 
	resulting string.
	
	Parameters:
		strSource: Source string
		strSearch: Substring to search for and remove
		strReplace: Substring to be inserted into string.
		
	Syntax:
	myNewString = azlwEMUreplaceSubStr(strSource, strSearch, strReplace);
  	========================================================

*/
	if (!strSource) return "";
	if (!strSearch) return strSource;
	if (!strReplace) strReplace = "";

	var idxPos = strSource.indexOf(strSearch);
	if (idxPos < 0) return strSource;
	var retVal = strSource;
	
	do {
		retVal = retVal.replace(strSearch, strReplace);
		idxPos = retVal.indexOf(strSearch);
	} while (idxPos >= 0);
	
	return retVal;
	
} // function azlwEMUreplaceSubStr()


function azlwEMUfixDiv(cssClassName) {
/**
	========================================================
	This function replaces obfuscated mailto email information with the 
	correct information.  It does this by searching for <div> elements that are 
	named with a specific format.  For each <div> element found, this function
	processes the innerHTML and style attribute to create a properly formatted 
	mailto href.
	
	This function should be called after the document loads, to ensure that all
	appropriate <div> elements are fully populated.  The most common way
	to do this is via a setTimeout call in the document body onload event.
	
	Syntax: 
	azlwEMUfixDiviv();  or azlwEMUfixDiviv("myClass");
	
	Common use syntax: 
	setTimeout("azlwEMUfixDiviv();", 3200); or setTimeout("azlwEMUfixDiviv('myClass');", 3200);
	
	Parameters:
	cssClassName : OPTIONAL.  The name of a css class to apply to the href.
	If blank, then no class is assigned.  
	
	<div> element naming pattern:
	<div id="azlwEMU_DIVPREFIX_n">, where n is an integer, starting at 1 and incrementing
	for each <div> element to be processed.
		
	The <div> element MUST have a style attribute.  It is recommended that
	this sytle be set to "display:none";
	
	<div> element innerHTML construction:
	
	DisplayName|EmailAddress
	
	DisplayName : The name to display in the UI for the mailto href.
	|	: pipe character (required)
	EmailAddress: The email address to use in the mailto href.
	
	DisplayName and EmailAddress should be constructed using any 
	combination of the following "spacer" characters interspersed between
	the individual characters:
	"?"	: Question Mark
	"`"	: Apostrophe (NOT a single quote character)
	"~"	: Tilde
	"#"	: Pound (Number) sign
	"$"	: Dollar sign
	"^"	: Carat
	"*"	: Asterisk
	"("	: Left parenthesis
	")"	: Right parenthesis
	"{"	: Left brace
	"}"	: Right brace
	"["	: Left bracket
	"]"	: Right bracket

	Additionally, the @ symbol in the Email address should be replaced with
	the string "_AT_".
	
	Example:
	Assuming the following <div> element exists on the document:
	
	<div id="azlwEMU_DIVPREFIX_0" style="display:none">W?e`b~ #M$a^s*t(e)r{|}j[o]e?.`s~m#i$t^h*_AT_(a)b{c}.[c]o?m`~</div>
	
	When divD() is called, it will get a handle to this <div> element, and process it 
	to produce the following: 

	<div id="azlwEMU_DIVPREFIX_0" style="display:inline"><a href='mailto:joe.smith@abc.com'>Web Master</a></div>
	
	CAVEATS:
	Any blank spaces included in the <div> element's innerHTML will be 
	reproduced exactly in the resulting mailto href.  While this is fine for the 
	DisplayName part, 	they can produce broken or incorrect links if they occur 
	in the EmailAddress part.
	
	The function always starts at the zeroth ("azlwEMU_DIVPREFIX_0") 
	element.
	
	This function looks searches for all <div id="azlwEMU_DIVPREFIX_n"> 
	elements, where n is an integer starting at 1 and incrementing by 1 for 
	each successive <div> element to be processed.  If the function cannot 
	find a named element, it immediately stops processing.  This means that 
	if you have <div> elements named "azlwEMU_DIVPREFIX_0", 
	"azlwEMU_DIVPREFIX_1", "azlwEMU_DIVPREFIX_2", 
	"azlwEMU_DIVPREFIX_4", "azlwEMU_DIVPREFIX_5", etc (NOTE there 
	is no "azlwEMU_DIVPREFIX_3"); only the <div> elements named 
	"azlwEMU_DIVPREFIX_0", "azlwEMU_DIVPREFIX_1" and 
	"azlwEMU_DIVPREFIX_2" will be processed.  Because the code does 
	not find anything named "azlwEMU_DIVPREFIX_3"; it therefore stops 
	processing after "azlwEMU_DIVPREFIX_2".  The  successively named 
	<div> elements ("azlwEMU_DIVPREFIX_4", "azlwEMU_DIVPREFIX_5", 
	etc.) will be ignored.	
	========================================================
*/

	if ((!document.getElementById) && (!document.all)) {
		window.status = "Neither document.getElementById() or document.all[] is supported.";
		return false;
	} // if ((!document.getElementById) && (!document.all))

	var sWork = "";
	var sLabel = "";
	var sEmail = "";
	var sHREF = "";
	var i = 0;

	if (azlwEMU_BYID) {
		var objDiv = document.getElementById(azlwEMU_DIVPREFIX + i);
	} else {
		var objDiv = document.all[azlwEMU_DIVPREFIX + i];
	} // if (azlwEMU_BYID)

	if (!objDiv) return false;  // no matching element was found, bail out.

	while(objDiv) {
	// An element was found.  
		sWork = objDiv.innerHTML;
		if(sWork != "") {
			for (j = 0; j<= azlwEMU_OBFUSCHARS.length; j++) {
				sWork = sWork.split(azlwEMU_OBFUSCHARS[j]).join("");
			} // for (j = 1; j<= azlwEMU_OBFUSCHARS.length; j++)
			sWork = sWork.split(azlwEMU_OBFUSAT).join(azlwEMU_CLEARAT);
			if (sWork.indexOf(azlwEMU_DELIM) > 0) {
				sWork = sWork.split(azlwEMU_DELIM);
				sLabel = sWork[0];
				sEmail = sWork[1]
			} else {
				sLabel = sWork;
				sEmail = sWork;
			} // if (sWork.indexOf(azlwEMU_DELIM) > 0) 			

			sHREF = "<a href='mailto:" + sEmail + "'";
			if ((cssClassName) && (cssClassName != "")) sHREF += " class='" + cssClassName + "'";
			sHREF += ">" + sLabel + "</a>";
			objDiv.innerHTML = sHREF;
			if (objDiv.style) objDiv.style.display = "inline";
		} // if(sWork != "")
		i++;
		
		if (azlwEMU_BYID) {
			var objDiv = document.getElementById(azlwEMU_DIVPREFIX + i);
		} else {
			var objDiv = document.all[azlwEMU_DIVPREFIX + i];
		} // if (azlwEMU_BYID)
	} // while(objDiv)
	
	return true;
	
} // function azlwEMUfixDiv()


function azlwEMUobfuscateString(SourceValue) {
/**
	========================================================
	This function will obfuscate a passed in string by 
	inserting obfuscation characters into the string.
	The resulting string will be returned.
	========================================================
*/	

	var strSource = SourceValue.toString();
	
	if ((!strSource) || (strSource == "")) return "";

	var retVal = "";
	var j = 0;
	for (var i=0; i<strSource.length; i++) {
		if (j >= azlwEMU_OBFUSCHARS.length) j = 0;
		retVal += azlwEMU_OBFUSCHARS[j];

		if (strSource.charAt(i) == azlwEMU_CLEARAT) {
			retVal += azlwEMU_OBFUSAT;
		} else {
			retVal += strSource.charAt(i);
		} // if (strSource.charAt(i) == azlwEMU_CLEARAT)
	
		j++;
		
	} // for (var i=0; i<strSource.length; i++)

	if (j > azlwEMU_OBFUSCHARS.length) j = 0;
	retVal += azlwEMU_OBFUSCHARS[j];
	
	return retVal;

} // function azlwEMUobfuscateString()


function azlwEMUobfuscateMailInfo(idLabels, idEmails, idTarget) {
/**
	========================================================
	This function will obfuscate mailto information and write
	the obfuscated information to a target field.
	
	Parameters:
	idLabels : REQUIRED.  The id of a TEXTAREA on the form to
		pull email label information from.

	idEmails : REQUIRED.  The id of a TEXTAREA on the form to
		pull email address information from.
	
	idTarget : REQUIRED.  The id of a TEXTAREA on the form to
		write the obfuscated html to.

	If any of the parameters are missing, this function will 
	notify the user and exit.
	
	If any of the objects identified by the parameters are 
	missing, this function will notify the user and exit.
	
	If the browser does not support either of the methods 
	document.getElementById() or document.all[], this function 
	will notify the user and exit.		
	========================================================
*/
	if ((!idLabels) || (!idEmails) || (!idTarget)) {
		alert("Error: call to function azlwEMUobfuscateMailInfo() is missing required arguments.");
		return false;
	} // if ((!idLabels) || (!idEmails) || (!idTarget))

	var objLabels = false;
	var objEmails = false;
	var objTarget = false;

	if (azlwEMU_BYID) {
		objLabels = document.getElementById(idLabels);
		objEmails = document.getElementById(idEmails);
		objTarget = document.getElementById(idTarget);
	} else {
		objLabels = document.all[idLabels];
		objEmails = document.all[idEmails];
		objTarget = document.all[idTarget];
	} // if (azlwEMU_BYID)

	if (!objLabels) {
		alert("Error: Document Object Not Found: \n" + idLabels);
		return false;
	} // if (!objLabels)

	if (!objEmails) {
		alert("Error: Document Object Not Found: \n" + idEmails);
		return false;
	} // if (!objEmails)

	if (!objTarget) {
		alert("Error: Document Object Not Found: \n" + idTarget);
		return false;
	} // if (!objTarget)

	var Labels = Trim(objLabels.value);
	var Emails = Trim(objEmails.value);

	if (Emails == "") {
		alert("Error: No Email addresses found.");
		return false;
	} // if (Emails == "")  

	var arraySearch = new Array(String.fromCharCode(10), String.fromCharCode(13), ";", ",", azlwEMU_DELIM + azlwEMU_DELIM);

	for (var i=0; i<arraySearch.length; i++) {
		Labels = azlwEMUreplaceSubStr(Labels, arraySearch[i], azlwEMU_DELIM);
		Emails = azlwEMUreplaceSubStr(Emails, arraySearch[i], azlwEMU_DELIM);
	} // (var i=0; i<arraySearch.length; i++)

	Emails = Emails.split(azlwEMU_DELIM);
	
	for (var i=0; i<Emails.length; i++) {
		Emails[i] = Trim(Emails[i])
	} // for (var i=0; i<Email.length; i++)

	Emails = removeEmpties(Emails);

	if (Labels == "") {
		Labels = new Array(Emails.length);
	} else {
		Labels = Labels.split(azlwEMU_DELIM);
	} // if (Labels == "")

	Labels.length = Emails.length;
	for (var i=0; i<Labels.length; i++) {
		if (!Labels[i]) Labels[i] = "";
		if (Labels[i].toString() == "undefined") Labels[i] = "";
		if (Labels[i].toString() != "") Labels[i] = Trim(Labels[i]);
	} // for (var i=0; i<Labels.length; i++)

	var divStart1 = "<div id=\"" + azlwEMU_DIVPREFIX;
	var divStart2 = "\" style=\"display:none;\">";
	var divEnd1 = "</div><!-- " + azlwEMU_DIVPREFIX;
	var divEnd2 = " -->";
	
	var arrayTarget = new Array(Emails.length);
	var Temp = "";
	var TargetLabel = "";
	var TargetEmail = "";
	
	for (var i=0; i<Emails.length; i++) {
		TargetLabel = azlwEMUobfuscateString(Labels[i]);
		TargetEmail = azlwEMUobfuscateString(Emails[i]);
						
		if (TargetLabel == "") {
			Temp = TargetEmail;
		} else {
			Temp = TargetLabel + azlwEMU_DELIM + TargetEmail;
		} // if (TargetLabel == "")
		
		arrayTarget[i] = divStart1 + i + divStart2 + Temp + divEnd1 + i + divEnd2;
	} // for (var i=0; i<Emails.length; i++)

	objTarget.value = arrayTarget.join("<br />\n");

} // function azlwEMUobfuscateMailInfo()



function Trim(SourceValue) {
/**
	========================================================
	This function will trim leading and trailing spaces off 
	of a string value and return the result.
	FUNCTION ONLY REMOVES BLANK SPACES (" "), NOT WHITESPACE 
	(such as hard returns, line feeds, tabs, etc.)
	========================================================
*/
	if (!SourceValue) return "";
	if (!SourceValue.toString) return "";
	return LTrim(RTrim(SourceValue.toString()));
} // function Trim()


function RTrim(SourceValue) {
/**
	========================================================
	This function will trim trailing spaces off of a string 
	value and return the result.
	FUNCTION ONLY REMOVES BLANK SPACES (" "), NOT WHITESPACE 
	(such as hard returns, line feeds, tabs, etc.)
	========================================================
*/
	var retVal = SourceValue.toString();
	while ((retVal.length > 0) && (retVal.charAt(retVal.length -1) == " ")) retVal = retVal.substr(0, retVal.length -1); 
	return retVal;
} // function RTrim


function LTrim(SourceValue){
/**
	========================================================
	This function will trim leading spaces off of a string 
	value and return the result.
	FUNCTION ONLY REMOVES BLANK SPACES (" "), NOT WHITESPACE 
	(such as hard returns, line feeds, tabs, etc.)
	========================================================
*/
	var retVal = SourceValue.toString();
	while ((retVal.length > 0) && (retVal.charAt(0) == " ")) retVal = retVal.substr(1, retVal.length);
	return retVal;
} // function LTrim()


function removeEmpties(arraySource) {
/**
	========================================================
	This function will remove empty elements from an array 
	of strings, and return the "cleaned up" array.
	========================================================
*/
	var retVal = new Array("");
	var added = false;
	for (var i=0; i<arraySource.length; i++) {
		if (arraySource[i].toString() != "") {
			if (added) {
				retVal[retVal.length - 1] = arraySource[i];
			} else {
				retVal[0] = arraySource[i];
				added = true;
			} // if (added)
	
			retVal[retVal.length] = "";
		} // if (arraySource[i].toString() != "")
	} // for (var i=0; i<arraySource.length; i++)
	
	if (added) retVal.length = retVal.length -1;
		
	return retVal;
	
} // function removeEmpties()

